@@ -200,7 +200,15 @@ def _load_mpc_from_mat_file(input_file):
     mpc['bus'] = prepare_data(mat['bus'])
     mpc['branch'] = prepare_data(mat['branch'])
     mpc['gen'] = prepare_data(mat['gen'])
-    mpc['gencost'] = prepare_data(mat['gencost'])
+    try:
+        mpc['gencost'] = prepare_data(mat['gencost'])
+    except (ValueError, KeyError):
+        # If the generator cost is missing, set all costs to zero
+        cgen = GeneratorConstants
+        mpc['gencost'] = np.zeros((mpc['gen'].shape[0], cgen.COST + 2),
+                                  dtype=hynet_float_)
+        mpc['gencost'][:, cgen.MODEL] = cgen.POLYNOMIAL
+        mpc['gencost'][:, cgen.NCOST] = 2  # Linear 'zero cost' function
     try:
         mpc['dcline'] = prepare_data(mat['dcline'])
     except (ValueError, KeyError):
@@ -380,6 +388,30 @@ def import_matpower_test_case(input_file, output_file=None, grid_name=None,
     if grid_name is None:
         grid_name = os.path.basename(os.path.splitext(input_file)[0])
 
+    # Detect 'Inf' values and, if appropriate, replace them
+    for field in ['bus', 'branch', 'gen', 'gencost', 'dcline']:
+        idx_inf = np.where(np.isinf(mpc[field]))
+        if not idx_inf[0].size:
+            continue
+        if (field == 'gen' and
+                np.all(np.isin(idx_inf[1], [cgen.PMIN, cgen.PMAX,
+                                            cgen.QMIN, cgen.QMAX]))) or \
+           (field == 'dcline' and
+                np.all(np.isin(idx_inf[1], [cdcl.PMIN, cdcl.PMAX,
+                                            cdcl.QMINF, cdcl.QMINT,
+                                            cdcl.QMAXF, cdcl.QMAXT]))):
+            INF_REPLACEMENT = 1e4
+            _log.warning(("The field '{:s}' contains (+/-) 'Inf' "
+                          "active/reactive power limits in the rows {:s}. "
+                          "These are replaced by (+/-) {:g} GW/Gvar.")
+                         .format(field,
+                                 str(list(np.unique(idx_inf[0]) + 1)),
+                                 INF_REPLACEMENT/1e3))
+            mpc[field][idx_inf] = np.sign(mpc[field][idx_inf]) * INF_REPLACEMENT
+        else:
+            raise ValueError("The field '{:s}' contains 'Inf' values."
+                             .format(field))
+
     scenario_id = 0             # Scenario ID for the base case
     base_case_inactivity = []   # Track base case inactivity for scenarios
     base_kv = {}                # Track bus base volt. for transformer detection
