@@ -11,7 +11,7 @@ from sqlalchemy import func
 from sqlalchemy.orm import make_transient
 from sqlalchemy.orm.exc import NoResultFound
 
-from hynet.data.connection import DBTransaction
+from hynet.data.connection import DBConnection, DBTransaction
 from hynet.data.structure import (DBInfo,
                                   DBScenario,
                                   DBBus,
@@ -189,8 +189,8 @@ def load_scenario(database, scenario_id=0):
     scenario.database_uri = database.database_uri
 
     scenario.grid_name = database.get_setting(DBInfoKey.GRID_NAME)
-    scenario.base_mva = hynet_float_(database.get_setting(DBInfoKey.BASE_MVA))
     scenario.description = database.get_setting(DBInfoKey.DESCRIPTION)
+    scenario.base_mva = hynet_float_(database.get_setting(DBInfoKey.BASE_MVA))
 
     with DBTransaction(database) as transaction:
         # General grid information
@@ -214,7 +214,7 @@ def load_scenario(database, scenario_id=0):
 
         # Map the bus types to their enumeration value
         scenario.bus['type'] = \
-            scenario.bus['type'].map(lambda t: BusType(t)).values
+            scenario.bus['type'].map(lambda t: BusType(t)).to_numpy()
 
         # Fix data type issues with the zone column
         scenario.bus['zone'] = fix_hynet_id(scenario.bus['zone'])
@@ -257,7 +257,7 @@ def load_scenario(database, scenario_id=0):
 
         # Map the branch types to their enumeration value
         scenario.branch['type'] = \
-            scenario.branch['type'].map(lambda t: BranchType(t)).values
+            scenario.branch['type'].map(lambda t: BranchType(t)).to_numpy()
 
         # Calculate the series impedance and shunt admittances
         scenario.branch['z_bar'] = \
@@ -324,7 +324,7 @@ def load_scenario(database, scenario_id=0):
 
         # Map the injector types to their enumeration value
         scenario.injector['type'] = \
-            scenario.injector['type'].map(lambda t: InjectorType(t)).values
+            scenario.injector['type'].map(lambda t: InjectorType(t)).to_numpy()
 
         # Map the injector cap. region IDs to objects
         scenario.injector['cap'] = scenario.injector['cap_id'].map(
@@ -609,9 +609,9 @@ def initialize_database(database, scenario):
     if not database.empty:
         raise ValueError("The specified database is not empty.")
 
-    scenario.verify()
-    if np.any(scenario.branch['y_src'].values.real != 0) or \
-            np.any(scenario.branch['y_dst'].values.real != 0):
+    scenario.verify(log=None)
+    if np.any(scenario.branch['y_src'].to_numpy().real != 0) or \
+            np.any(scenario.branch['y_dst'].to_numpy().real != 0):
         raise ValueError("Branches with a nonzero shunt conductance are "
                          "not supported.")
 
@@ -621,14 +621,13 @@ def initialize_database(database, scenario):
     # Helper variable for generating IDs
     scenario.counter_cap_region_id = 0
 
-    # Write general settings, grid infrastructure data, and scenario data
+    # Write general settings
+    database.grid_name = scenario.grid_name
+    database.description = scenario.description
+    database.set_setting(DBInfoKey.BASE_MVA, str(scenario.base_mva))
+
+    # Write grid infrastructure data and scenario data
     with DBTransaction(database) as transaction:
-        transaction.add(DBInfo(key=DBInfoKey.GRID_NAME,
-                               value=scenario.grid_name))
-        transaction.add(DBInfo(key=DBInfoKey.BASE_MVA,
-                               value=scenario.base_mva))
-        transaction.add(DBInfo(key=DBInfoKey.DESCRIPTION,
-                               value=scenario.description))
 
         transaction.add(DBScenario(id=scenario.id,
                                    time=scenario.time,
@@ -712,7 +711,7 @@ def save_scenario(database, scenario, auto_id=True):
     if database.empty:
         raise ValueError("The specified database is empty.")
 
-    scenario.verify()
+    scenario.verify(log=None)
 
     # Helper variable for generating IDs
     scenario.counter_cap_region_id = 0
@@ -953,7 +952,7 @@ def remove_scenarios(database, scenario_ids):
     # Check if all scenarios exist
     scenario_info = get_scenario_info(database)
     for scenario_id in scenario_ids:
-        if not scenario_info.index.contains(scenario_id):
+        if scenario_id not in scenario_info.index:
             raise ValueError("The database does not contain a scenario with "
                              "the ID '{:d}'.".format(scenario_id))
 
@@ -997,7 +996,7 @@ def copy_scenarios(source_database, destination_database,
         Connection to the destination *hynet* grid database.
     scenario_ids : list[.hynet_id_], optional
         List of scenario identifiers that shall be copied. By default, all
-        scenarios except the "base case" with scenario ID 0 are copied.
+        scenarios are copied.
     bus_id_map : pandas.Series, optional
         If provided, this series, *indexed by the bus IDs in the source
         database*, specifies the mapping of a bus ID in the source database to
@@ -1016,7 +1015,7 @@ def copy_scenarios(source_database, destination_database,
         bus_id_map = pd.Series(_id_range, index=_id_range)
 
     for scenario_id in scenario_ids:
-        if dst_scenario_ids.contains(scenario_id):
+        if scenario_id in dst_scenario_ids:
             _log.warning("Scenario with ID '{:d}' already exists. Skipping it."
                          .format(scenario_id))
             continue
