@@ -326,7 +326,7 @@ class ConverterCapRegion(CapRegion):
     at the respective terminal bus of the converter, see ``CapRegion`` for
     more information. With respect to the parameters returned by
     ``get_polyhedron`` and ``get_box_constraint``, this class considers the
-    converter state variable ``f = [p_src, p_dst, q_src, q_dst]^T`` instead
+    converter state variable ``f = [p_fwd, p_bwd, q_src, q_dst]^T`` instead
     of the apparent power vector ``s = [p, q]^T`` considered in ``CapRegion``.
 
     See Also
@@ -337,9 +337,10 @@ class ConverterCapRegion(CapRegion):
         """
         Returns the polyhedron formulation ``S_phd = { f in R^4: A*f <= b }``.
 
-        **Remark:** In contrast to ``CapRegion``, the polyhedron does not only
-        include the half-spaces, but also the upper and lower bound on active
-        power.
+        In addition to the half-spaces of the capability region, this
+        polyhedron includes, for bidirectional converters with a nonnegligible
+        capacity, an additional constraint to limit the noncomplementary
+        operation of the converter.
 
         Parameters
         ----------
@@ -375,35 +376,103 @@ class ConverterCapRegion(CapRegion):
         else:
             raise ValueError("Expecting 'src' or 'dst' for terminal.")
 
-        # Reformulate polyhedron in terms of f and add active power LB and UB
+        # Reformulate polyhedron in terms of f
         F = np.array(F, dtype=hynet_float_)
         A, b, name = super().get_polyhedron()
-        A = np.vstack((A.dot(F), F[0, :], -F[0, :]))
-        b = np.concatenate((b, [self.p_max, -self.p_min]))
-        name += ['p_max', 'p_min']
+        A = A.dot(F)
+
+        # Limit the noncomplementary (mixed) mode of the converter:
+        #
+        # The converter model is designed for complementary modes
+        # (p_fwd*p_bwd = 0), i.e., only p_fwd *or* p_bwd should be nonzero as
+        # otherwise a loss error may emerge. While the box constraints
+        # restrict the forward and backward flow to their respective limits,
+        # there remains a rectangular region in the p_fwd/p_bwd-plane. To
+        # limit noncomplementary operation as good as possible while retaining
+        # a convex formulation, an additional limitation to the convex hull
+        # of (0,0), (p_fwd_ub,0), and (0,p_bwd_ub) is introduced (for
+        # bidirectional converters), in which p_fwd_ub and p_bwd_ub denote the
+        # individual limits on the modes imposed by this converter capability
+        # region.
+        #
+        # For numerical reasons, the additional constraint defined by the
+        # half-space through (p_fwd_ub,0) and (0,p_bwd_ub) is only added if the
+        # rectangular region is of nonnegligible size. Furthermore, the half-
+        # space is slightly shifted "outwards" (away from the origin) to avoid
+        # any (numerical) impact on the box constraint and its dual variables.
+        if self.p_max >= 1 and self.p_min <= -1:
+            if terminal == 'src':
+                p_fwd_ub = +self.p_max
+                p_bwd_ub = -self.p_min / (1 - loss_factor)
+            else:
+                p_fwd_ub = -self.p_min / (1 - loss_factor)
+                p_bwd_ub = +self.p_max
+            A = np.vstack((A, [1.0/p_fwd_ub, 1.0/p_bwd_ub, 0, 0]))
+            b = np.concatenate((b, [1 + 1e-4]))
+            name += ['_mixed_mode_limit']
+
         return A, b, name
 
     @staticmethod
-    def get_box_constraint(cap_src, cap_dst):
+    def get_box_constraint(cap_src, cap_dst, loss_factor_fwd, loss_factor_bwd):
         """
         Return ``(f_lb, f_ub)`` of the state constraint ``f_lb <= f <= f_ub``.
 
         A converter comprises two capability regions, one at the source terminal
-        (``cap_src``) and one at the destination terminal (``cap_dst``). Thus,
-        the box constraint on the converter state variable is a combination of
-        both and returned by this function. Note that the active power
-        constraints are included in ``get_polyhedron`` and the upper bounds on
-        ``p_src`` and ``p_dst`` in ``f`` are merely additional loosened
-        upper bounds (cf. the remark in ``get_voltage_magnitude_bounds`` of
-        ``SystemModel``).
+        and one at the destination terminal. Thus, the box constraint on the
+        converter state variable is a combination of both as well as the
+        conversion loss factors.
+
+        Parameters
+        ----------
+        cap_src : ConverterCapRegion
+            Source terminal capability region.
+        cap_dst : ConverterCapRegion
+            Destination terminal capability region.
+        loss_factor_fwd : float
+            Proportional loss factor for the *forward* flow.
+        loss_factor_bwd : float
+            Proportional loss factor for the *backward* flow.
+
+        Returns
+        -------
+        f_lb : np.ndarray[.hynet_float_]
+            Lower bound on the converter state vector.
+        f_ub : np.ndarray[.hynet_float_]
+            Upper bound on the converter state vector.
         """
-        f_lb = np.zeros(4, dtype=hynet_float_)  # LB on p_src, p_dst is 0
+        if not (0 <= loss_factor_fwd < 1 and 0 <= loss_factor_bwd < 1):
+            raise ValueError("Loss factors must be in [0,1).")
+
+        p_fwd_ub = min(
+            +max(0.0, cap_src.p_max),
+            -min(0.0, cap_dst.p_min) / (1 - loss_factor_fwd)
+        )
+
+        p_bwd_ub = min(
+            +max(0.0, cap_dst.p_max),
+            -min(0.0, cap_src.p_min) / (1 - loss_factor_bwd)
+        )
+
+        p_fwd_lb = max(
+            +max(0.0, cap_src.p_min),
+            -min(0.0, cap_dst.p_max) / (1 - loss_factor_fwd)
+        )
+
+        p_bwd_lb = max(
+            +max(0.0, cap_dst.p_min),
+            -min(0.0, cap_src.p_max) / (1 - loss_factor_bwd)
+        )
+
+        f_lb = np.zeros(4, dtype=hynet_float_)
+        f_lb[0] = p_fwd_lb
+        f_lb[1] = p_bwd_lb
         f_lb[2] = cap_src.q_min  # q_src
         f_lb[3] = cap_dst.q_min  # q_dst
 
         f_ub = np.zeros(4, dtype=hynet_float_)
-        f_ub[0] = np.max([abs(cap_src.p_max), abs(cap_dst.p_min)]) * 1.1  # p_src
-        f_ub[1] = np.max([abs(cap_dst.p_max), abs(cap_src.p_min)]) * 1.1  # p_dst
+        f_ub[0] = p_fwd_ub
+        f_ub[1] = p_bwd_ub
         f_ub[2] = cap_src.q_max  # q_src
         f_ub[3] = cap_dst.q_max  # q_dst
 
