@@ -58,7 +58,7 @@ class QCQPSolver(SolverInterface):
     References
     ----------
     .. [1] https://github.com/matthias-k/cyipopt
-    .. [2] https://projects.coin-or.org/Ipopt
+    .. [2] https://github.com/coin-or/Ipopt
     .. [3] https://www.coin-or.org/Ipopt/documentation/node40.html
     """
 
@@ -67,7 +67,7 @@ class QCQPSolver(SolverInterface):
         # REMARK: Experimentally, we found that this default setting provides a
         # good compromise between accuracy and performance.
         if 'tol' not in self.param:
-            self.param['tol'] = 1e-7
+            self.param['tol'] = 1e-6
 
     @property
     def name(self):
@@ -134,12 +134,7 @@ class IPOPTProblem(ipopt.problem):
         Initialize the problem formulation and prepare for the solution process.
         """
         (e_src, e_dst) = qcqp.edges
-        if np.any(e_src >= e_dst):
-            raise RuntimeError("For simplicity, this solver assumes "
-                               "that the source node index is smaller "
-                               "than the destination node index in the "
-                               "sparsity specification. At the time of "
-                               "implementation, this was the default.")
+        assert np.all(e_src > e_dst)  # Sparsity pattern of lower-triangular part
 
         self.qcqp = qcqp
         UNBOUNDED = 2.0e19  # Bounds are ignored if larger/smaller than +/- 10^19
@@ -320,7 +315,7 @@ class IPOPTProblem(ipopt.problem):
             [      ...       |       ...       |         ...          ]
             [ 2*Re(C_N v)^T  |  2*Im(C_N v)^T  |  c_N^T  a_N^T  r_N^T ]
 
-            \_______________/ \_______________/ \____________________/
+           \\_______________/\\_______________/\\____________________/
                    (1)               (2)                 (3)
 
         Block (3) remains constant for all iterations and is precomputed during
@@ -356,9 +351,12 @@ class IPOPTProblem(ipopt.problem):
         if workers.is_multiprocessing and \
                 len(list_jacobian_C) >= workers.num_workers:
             list_jacobian_C = workers.map(scipy.sparse.vstack,
-                                          partition_iterable(list_jacobian_C,
-                                                             workers.num_workers)
-                                          )
+                                          list(
+                                              partition_iterable(
+                                                  list_jacobian_C,
+                                                  workers.num_workers
+                                              )
+                                          ))
         jacobian_C = scipy.sparse.vstack(list_jacobian_C).tocsr()
 
         _log.debug("QCQP ~ Preparation of v-part in Jacobian ({:.3f} sec.)"
@@ -376,25 +374,25 @@ class IPOPTProblem(ipopt.problem):
         (or, alternatively, the upper triangular part) is specified.
 
         **Remark:** This method as well as ``_get_hessian_data`` assumes that
-        ``e_src >= e_dst``, where ``(e_src, e_dst) = qcqp.edges``. This is
-        ensured during initialization.
+        ``e_src > e_dst``, where ``(e_src, e_dst) = qcqp.edges``. This is
+        asserted during initialization.
         """
         (e_src, e_dst) = qcqp.edges
         range_v = np.arange(qcqp.dim_v)
 
         row = np.concatenate((range_v,               # Diag. top-left
                               range_v + qcqp.dim_v,  # Diag. bottom-right
-                              e_dst,                 # Off-diag. top-left
-                              e_dst + qcqp.dim_v,    # Off-diag. bottom-right
-                              e_src + qcqp.dim_v,    # Off-diag. bottom-left
-                              e_dst + qcqp.dim_v))   # Off-diag. bottom-left
+                              e_src,                 # Off-diag. top-left LT
+                              e_src + qcqp.dim_v,    # Off-diag. bottom-right LT
+                              e_src + qcqp.dim_v,    # Off-diag. bottom-left LT
+                              e_dst + qcqp.dim_v))   # Off-diag. bottom-left UT
 
         col = np.concatenate((range_v,               # Diag. top-left
                               range_v + qcqp.dim_v,  # Diag. bottom-right
-                              e_src,                 # Off-diag. top-left
-                              e_src + qcqp.dim_v,    # Off-diag. bottom-right
-                              e_dst,                 # Off-diag. bottom-left
-                              e_src))                # Off-diag. bottom-left
+                              e_dst,                 # Off-diag. top-left LT
+                              e_dst + qcqp.dim_v,    # Off-diag. bottom-right LT
+                              e_dst,                 # Off-diag. bottom-left LT
+                              e_src))                # Off-diag. bottom-left UT
         return row, col
 
     @staticmethod
